@@ -1,14 +1,10 @@
 from django.conf.urls.defaults import *
 from piston.resource import Resource
-from piston.authentication import HttpBasicAuthentication
 
 from lizard_map.api.handlers import MapPluginsHandler
 
 
-auth = HttpBasicAuthentication(realm="Fews jdbc")
-ad = { 'authentication': auth }
-
-map_plugins_handler = Resource(MapPluginsHandler, **ad)
+map_plugins_handler = Resource(MapPluginsHandler)
 
 urlpatterns = patterns(
     '',
