@@ -1,6 +1,7 @@
 /*jslint browser: true */
 /*jslint evil: true */
-/*global $, OpenLayers, popup_click_handler, popup_hover_handler, alert */
+/*global $, OpenLayers, popup_click_handler, popup_hover_handler, alert,
+G_PHYSICAL_MAP, TouchHandler */
 var layers, map;
 layers = [];
 
@@ -47,7 +48,7 @@ function showMap() {
             displayProjection: new OpenLayers.Projection(display_projection),  // "EPSG:4326"
             units: "m",
             numZoomLevels: 18,
-            maxExtent: new OpenLayers.Bounds(129394, 6659216, 1335570, 7306790)
+            maxExtent: new OpenLayers.Bounds(-20037508.34, -20037508.34, 20037508.34, 20037508.34)
         };
     }
     else if (projection === "EPSG:28992")
@@ -89,6 +90,12 @@ function showMap() {
             {'isBaseLayer': true, 'buffer': 1}
         );
     }
+    else if (base_layer_type === "GOOGLE")
+    {
+        base_layer = new OpenLayers.Layer.Google(
+            "Google Physical",
+            {type: G_PHYSICAL_MAP, sphericalMercator: true});
+    }
     map.addLayer(base_layer);
 
     // Add our own data layers.
@@ -191,6 +198,8 @@ function showMap() {
     map.setCenter(
         new OpenLayers.LonLat(parseFloat(startlocation_x), parseFloat(startlocation_y)),
         parseFloat(startlocation_zoom));
+
+
 }
 
 
