@@ -7,7 +7,7 @@ admin.autodiscover()
 
 urlpatterns = patterns(
     '',
-
+    (r'^api/', include('lizard_map.api.urls')),
     # Actions/services on/from workspaces
     url(r'^workspace/(?P<workspace_id>\d+)/wms/',
         'lizard_map.views.wms',
@@ -18,6 +18,9 @@ urlpatterns = patterns(
     url(r'^workspace/(?P<workspace_id>\d+)/workspace_items/add/',
         'lizard_map.views.workspace_item_add',
         name="lizard_map_workspace_item_add"),
+    url(r'^workspace/(?P<workspace_id>\d+)/workspace_items/empty/',
+        'lizard_map.views.workspace_item_empty',
+        name="lizard_map_workspace_item_empty"),
     url(r'^workspace/(?P<workspace_id>\d+)/',
         'lizard_map.views.workspace',
         name="lizard_map_workspace"),
@@ -32,16 +35,25 @@ urlpatterns = patterns(
      {},
      name="lizard_map.set_animation_date"),
 
+    # Load and save map location
+    (r'^map_location_save$',
+     'lizard_map.views.map_location_save',
+     {},
+     'lizard_map.map_location_save'),
+    (r'^map_location_load_default$',
+     'lizard_map.views.map_location_load_default',
+     {},
+     'lizard_map.map_location_load_default'),
+
     # Collages and snippets
     url(r'^collage/(?P<collage_id>\d+)/$',
         'lizard_map.views.collage',
-        {'editable': False},
         name="lizard_map.collage"),
-    url(r'^collage/(?P<collage_id>\d+)/edit/$',
-        'lizard_map.views.collage',
-        {'editable': True,
-         'template': 'lizard_map/collage_edit.html'},
-        name="lizard_map.collage_edit"),
+    # url(r'^collage/(?P<collage_id>\d+)/edit/$',
+    #     'lizard_map.views.collage',
+    #     {'editable': True,
+    #      'template': 'lizard_map/collage_edit.html'},
+    #     name="lizard_map.collage_edit"),
     url(r'^collage/(?P<collage_id>\d+)/popup/$',
         'lizard_map.views.collage_popup',
         name="lizard_map.collage_popup"),
@@ -66,19 +78,26 @@ urlpatterns = patterns(
 
     # Partially the same actions as above,
     # you have to put workspace_id in GET parameter here...
-    url(r'^workspaceitemreorder/',
+    url(r'^workspaceitemreorder/$',
         'lizard_map.views.workspace_item_reorder',
         name="lizard_map_workspace_item_reorder"),
-    url(r'^workspaceitemadd/',
+    url(r'^workspaceitemadd/$',
         'lizard_map.views.workspace_item_add',
         name="lizard_map_workspace_item_add"),
+    url(r'^workspaceitem/extent/$',
+        'lizard_map.views.workspace_item_extent',
+        name="lizard_map_workspace_item_extent"),
 
     # Actions on your session workspace - the system looks for the right
     # workspace.
-    url(r'^session_workspace/',
+    url(r'^session_workspace/$',
         'lizard_map.views.session_workspace_edit_item',
         {'workspace_category': 'temp'},
         name="lizard_map_session_workspace_add_item_temp"),
+    url(r'^session_workspace/temp/extent/$',
+        'lizard_map.views.session_workspace_extent',
+        {'workspace_category': 'temp'},
+        name="lizard_map_session_workspace_extent_temp"),
 
     # Actions/services on session collages
     url(r'^session_collage/add/',
