@@ -160,12 +160,29 @@ class WorkspaceItemAdapter(object):
         else:
             self.layer_arguments = {}
 
-    def layer(self):
-        """Return xyz"""
+    def layer(self, layer_ids=None, request=None):
+        """Generates and returns layers, styles.
+
+        Layers is a list of mapnik layers.
+
+        Styles is a list of mapnik styles (which are used in the
+        layers).
+        """
         raise NotImplementedError
 
+    def extent(self, identifiers=None):
+        """
+        Returns extent {'west':.., 'north':.., 'east':.., 'south':..}
+        in google projection. None for each key means unknown.
+
+        Optional: If identifiers is given, return extent for those
+        identifiers only.
+        """
+        return {'north': None, 'south': None, 'east': None, 'west': None}
+
     def search(self, x, y, radius=None):
-        """Return list of dicts for matching items.
+        """Search by coordinates. Return list of dicts for matching
+        items.
 
         {'distance': <float>,
         'name': <name>,
@@ -175,6 +192,9 @@ class WorkspaceItemAdapter(object):
         'google_coords': (x, y) coordinate in google,
         'object': <object>} of closest fews point that matches x, y, radius.
 
+        Required: distance, name, workspace_item, google_coords
+        Highly recommended (else some functions will not work):
+        identifier (for popups)
         """
         raise NotImplementedError
 
@@ -338,12 +358,16 @@ class WorkspaceItemAdapter(object):
 
     def symbol_url(self, identifier=None, start_date=None, end_date=None,
                    icon_style=None):
-        """Return symbol for identifier"""
+        """Return symbol for identifier.
+
+        Implementation: respect the fact when icon_style is already
+        given. If it's empty, generate own icon if applicable.
+        """
         sm = SymbolManager(ICON_ORIGINALS, os.path.join(
                 settings.MEDIA_ROOT,
                 'generated_icons'))
         if icon_style is None:
-            icon_style = {'icon': 'brug.png'}
+            icon_style = {'icon': 'empty.png'}
         output_filename = sm.get_symbol_transformed(icon_style['icon'],
                                                     **icon_style)
         return settings.MEDIA_URL + 'generated_icons/' + output_filename
@@ -433,10 +457,14 @@ class WorkspaceItemAdapter(object):
 
     def legend(self, updates=None):
         """
-        Returns legend in a list of dictionaries.
+        Returns legend in a list of dictionaries. If this method
+        returns a list, then the legend icon will appear in your
+        workspace.
 
         Dictionary = {'img_url': <url>, 'description': <description>}
 
+        updates: ...
+
         """
         return []
 
@@ -451,7 +479,7 @@ class WorkspaceItemAdapter(object):
             logger.warn("Could not find legend for key '%s', "
                         "please configure the legend. "
                         "Now using fallback (red).")
-            color = Color(r=255, g=0, b=0)
+            color = Color('ff0000')
             found_legend = Legend(descriptor="", min_color=color,
                                   max_color=color, too_low_color=color,
                                   too_high_color=color)
@@ -459,9 +487,11 @@ class WorkspaceItemAdapter(object):
         return found_legend
 
     def legend_default(self, legend_object):
-        """Default implementation for legend. Use a fixed formula to
-        calculate legend descriptor, and img_url. Generates image if
-        needed. """
+        """Default implementation for legend. A legend is displayed
+        when the method "legend" is implemented in the adapter.
+
+        Use a fixed formula to calculate legend descriptor, and
+        img_url. Generates image if needed."""
 
         icon_style_template = {'icon': 'empty.png',
                                'mask': ('empty_mask.png', ),
@@ -473,10 +503,7 @@ class WorkspaceItemAdapter(object):
             # Add < min
             icon_style = icon_style_template.copy()
             icon_style.update({
-                    'color': (legend_object.too_low_color.r / 255.0,
-                              legend_object.too_low_color.g / 255.0,
-                              legend_object.too_low_color.b / 255.0,
-                              legend_object.too_low_color.a / 255.0)})
+                    'color': legend_object.too_low_color.to_tuple()})
             img_url = self.symbol_url(icon_style=icon_style)
             legend_result.append({'img_url': img_url,
                                   'description': (('< %s' % float_format) %
@@ -486,9 +513,7 @@ class WorkspaceItemAdapter(object):
             for legend_item in legend_object.legend_values():
                 color = legend_item['color']
                 icon_style = icon_style_template.copy()
-                icon_style.update({'color':
-                                   (color.r / 255.0, color.g / 255.0,
-                                    color.b / 255.0, color.a / 255.0)})
+                icon_style.update({'color': color.to_tuple()})
                 img_url = self.symbol_url(icon_style=icon_style)
                 legend_row = {'img_url': img_url,
                               'description': (
@@ -501,10 +526,7 @@ class WorkspaceItemAdapter(object):
             # Add > max
             icon_style = icon_style_template.copy()
             icon_style.update({
-                    'color': (legend_object.too_high_color.r / 255.0,
-                              legend_object.too_high_color.g / 255.0,
-                              legend_object.too_high_color.b / 255.0,
-                              legend_object.too_high_color.a / 255.0)})
+                    'color': legend_object.too_high_color.to_tuple()})
             img_url = self.symbol_url(icon_style=icon_style)
             legend_result.append({'img_url': img_url,
                                   'description': (('> %s' % float_format) %
